@@ -216,6 +216,14 @@ class CursorCommands(Commands):
         wnd.cursor.tol(wnd.cursor.pos)
         wnd.screen.selection.set_to(wnd.cursor.pos)
 
+    @command('cursor.first-letter-of-line')
+    @norerun
+    def first_letter(self, wnd):
+        wnd.document.mode.cancel_auto_indent(wnd)
+        wnd.screen.selection.end_cursor()
+        wnd.cursor.first_letter(wnd.cursor.pos)
+        wnd.screen.selection.set_to(wnd.cursor.pos)
+
     @command('cursor.end-of-line')
     @norerun
     def eol(self, wnd):
@@ -287,7 +295,7 @@ class CursorCommands(Commands):
         kaa.app.show_dialog(doc)
 
 
-class ScreenCommands(Commands):
+class SelectionCommands(Commands):
 
     @command('selection.begin-cursor')
     @norerun
@@ -373,14 +381,14 @@ class ScreenCommands(Commands):
             if kaa.app.macro.recording:
                 kaa.app.macro.record(self.select_cur_word)
 
-    @command('screen.lineselection.begin')
+    @command('selection.line.begin')
     @norerun
     def lineselection_begin(self, wnd):
         tol = wnd.cursor.adjust_nextpos(
             wnd.cursor.pos, wnd.document.gettol(wnd.cursor.pos))
         wnd.screen.selection.begin_cursor(tol)
 
-    @command('screen.lineselection.set-end')
+    @command('selection.line.set-end')
     @norerun
     def lineselection_set_end(self, wnd):
         f = wnd.screen.get_start()
@@ -848,46 +856,6 @@ class CodeCommands(Commands):
             wnd.cursor.savecol()
 
 
-class MacroCommands(Commands):
-
-    @command('macro.start-record')
-    @norec
-    @norerun
-    def start_record(self, wnd):
-        kaa.app.macro.start_record()
-        kaa.app.messagebar.update()
-
-    @command('macro.end-record')
-    @norec
-    @norerun
-    def end_record(self, wnd):
-        kaa.app.macro.end_record()
-        kaa.app.messagebar.update()
-
-    @command('macro.toggle-record')
-    @norec
-    @norerun
-    def toggle_record(self, wnd):
-        kaa.app.macro.toggle_record()
-        kaa.app.messagebar.update()
-
-    @command('macro.run')
-    @norec
-    def run_macro(self, wnd):
-        if kaa.app.macro.is_recording():
-            return
-        if not kaa.app.macro.get_commands():
-            return
-
-        if wnd.document.undo:
-            wnd.document.undo.beginblock()
-        try:
-            kaa.app.macro.run(wnd)
-        finally:
-            if wnd.document.undo:
-                wnd.document.undo.endblock()
-
-
 class SearchCommands(Commands):
 
     @command('search.showsearch')
@@ -972,17 +940,3 @@ class SearchCommands(Commands):
                 ret = wnd.document.mode.search_prev(wnd.document.endpos(),
                                                     modebase.SearchOption.LAST_SEARCH)
                 self._show_searchresult(wnd, ret)
-
-    @command('search.showgrep')
-    @norec
-    @norerun
-    def showgrep(self, wnd):
-        from kaa.ui.grep import grepdlgmode
-
-        buf = document.Buffer()
-        doc = document.Document(buf)
-        mode = grepdlgmode.GrepDlgMode(wnd)
-        doc.setmode(mode)
-        mode.build_document()
-
-        kaa.app.show_dialog(doc)
