@@ -127,18 +127,6 @@ class FilterListInputDlgMode(dialogmode.DialogMode):
         self.keybind.add_keybind(kaa.filetype.default.keybind.emacs_keys)
         self.keybind.add_keybind(filterlistinputdlg_keys)
 
-    def init_commands(self):
-        super().init_commands()
-
-        self.screen_commands = editorcommand.ScreenCommands()
-        self.register_command(self.screen_commands)
-
-        self.cursor_commands = editorcommand.CursorCommands()
-        self.register_command(self.cursor_commands)
-
-        self.edit_commands = editorcommand.EditCommands()
-        self.register_command(self.edit_commands)
-
     def on_add_window(self, wnd):
         super().on_add_window(wnd)
 
